@@ -58,7 +58,7 @@ def load(dependencies, override=False):
     s.resolve(schema.Resolver())
 
 
-def load_config(filenames, override=False):
+def load_config(filenames=['etc/ioc.conf', 'etc/ioc.conf.d/*'], override=True):
     for filepath in itertools.chain(*[glob.glob(x) for x in filenames]):
         with open(filepath) as f:
             load(yaml.safe_load(f.read()), override=override)
